==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/PowerQuerySinkMappingArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.PowerQuerySinkMappingArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Map Power Query mashup query to sink dataset(s).
 * @property dataflowSinks List of sinks mapped to Power Query mashup query.
 * @property queryName Name of the query in Power Query mashup document.
 */
public data class PowerQuerySinkMappingArgs(
    public val dataflowSinks: Output<List<PowerQuerySinkArgs>>? = null,
    public val queryName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.PowerQuerySinkMappingArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.PowerQuerySinkMappingArgs =
        com.pulumi.azurenative.datafactory.inputs.PowerQuerySinkMappingArgs.builder()
            .dataflowSinks(
                dataflowSinks?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .queryName(queryName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [PowerQuerySinkMappingArgs].
 */
@PulumiTagMarker
public class PowerQuerySinkMappingArgsBuilder internal constructor() {
    private var dataflowSinks: Output<List<PowerQuerySinkArgs>>? = null

    private var queryName: Output<String>? = null

    /**
     * @param value List of sinks mapped to Power Query mashup query.
     */
    @JvmName("rmdnlyppiicryciq")
    public suspend fun dataflowSinks(`value`: Output<List<PowerQuerySinkArgs>>) {
        this.dataflowSinks = value
    }

    @JvmName("qsbmobiiduijefwn")
    public suspend fun dataflowSinks(vararg values: Output<PowerQuerySinkArgs>) {
        this.dataflowSinks = Output.all(values.asList())
    }

    /**
     * @param values List of sinks mapped to Power Query mashup query.
     */
    @JvmName("ageabvmfukylcfrg")
    public suspend fun dataflowSinks(values: List<Output<PowerQuerySinkArgs>>) {
        this.dataflowSinks = Output.all(values)
    }

    /**
     * @param value Name of the query in Power Query mashup document.
     */
    @JvmName("libolufpuwubwrne")
    public suspend fun queryName(`value`: Output<String>) {
        this.queryName = value
    }

    /**
     * @param value List of sinks mapped to Power Query mashup query.
     */
    @JvmName("gsxetbisfsirhiox")
    public suspend fun dataflowSinks(`value`: List<PowerQuerySinkArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataflowSinks = mapped
    }

    /**
     * @param argument List of sinks mapped to Power Query mashup query.
     */
    @JvmName("nprtavetfpisnvmx")
    public suspend fun dataflowSinks(argument: List<suspend PowerQuerySinkArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            PowerQuerySinkArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.dataflowSinks = mapped
    }

    /**
     * @param argument List of sinks mapped to Power Query mashup query.
     */
    @JvmName("ptkrqejemhffwudv")
    public suspend fun dataflowSinks(vararg argument: suspend PowerQuerySinkArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            PowerQuerySinkArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.dataflowSinks = mapped
    }

    /**
     * @param argument List of sinks mapped to Power Query mashup query.
     */
    @JvmName("nefxvvreaetkiowg")
    public suspend fun dataflowSinks(argument: suspend PowerQuerySinkArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(PowerQuerySinkArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.dataflowSinks = mapped
    }

    /**
     * @param values List of sinks mapped to Power Query mashup query.
     */
    @JvmName("pixlhcintotfngly")
    public suspend fun dataflowSinks(vararg values: PowerQuerySinkArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dataflowSinks = mapped
    }

    /**
     * @param value Name of the query in Power Query mashup document.
     */
    @JvmName("ulvvfmcvaehiuyjp")
    public suspend fun queryName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.queryName = mapped
    }

    internal fun build(): PowerQuerySinkMappingArgs = PowerQuerySinkMappingArgs(
        dataflowSinks = dataflowSinks,
        queryName = queryName,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/PowerQuerySinkMappingArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.PowerQuerySinkMappingArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Map Power Query mashup query to sink dataset(s).
 * @property dataflowSinks List of sinks mapped to Power Query mashup query.
 * @property queryName Name of the query in Power Query mashup document.
 */
public data class PowerQuerySinkMappingArgs(
    public val dataflowSinks: Output<List<PowerQuerySinkArgs>>? = null,
    public val queryName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.PowerQuerySinkMappingArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.PowerQuerySinkMappingArgs =
        com.pulumi.azurenative.datafactory.inputs.PowerQuerySinkMappingArgs.builder()
            .dataflowSinks(
                dataflowSinks?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .queryName(queryName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [PowerQuerySinkMappingArgs].
 */
@PulumiTagMarker
public class PowerQuerySinkMappingArgsBuilder internal constructor() {
    private var dataflowSinks: Output<List<PowerQuerySinkArgs>>? = null

    private var queryName: Output<String>? = null

    /**
     * @param value List of sinks mapped to Power Query mashup query.
     */
    @JvmName("ipbbbapqahbgvcml")
    public suspend fun dataflowSinks(`value`: Output<List<PowerQuerySinkArgs>>) {
        this.dataflowSinks = value
    }

    @JvmName("suihdjaeryjrmojh")
    public suspend fun dataflowSinks(vararg values: Output<PowerQuerySinkArgs>) {
        this.dataflowSinks = Output.all(values.asList())
    }

    /**
     * @param values List of sinks mapped to Power Query mashup query.
     */
    @JvmName("paprstboneplqcns")
    public suspend fun dataflowSinks(values: List<Output<PowerQuerySinkArgs>>) {
        this.dataflowSinks = Output.all(values)
    }

    /**
     * @param value Name of the query in Power Query mashup document.
     */
    @JvmName("bfphpfltdvqokgnk")
    public suspend fun queryName(`value`: Output<String>) {
        this.queryName = value
    }

    /**
     * @param value List of sinks mapped to Power Query mashup query.
     */
    @JvmName("kboiafnosjrmlmyg")
    public suspend fun dataflowSinks(`value`: List<PowerQuerySinkArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataflowSinks = mapped
    }

    /**
     * @param argument List of sinks mapped to Power Query mashup query.
     */
    @JvmName("epsvrvhblajcksme")
    public suspend fun dataflowSinks(argument: List<suspend PowerQuerySinkArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            PowerQuerySinkArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.dataflowSinks = mapped
    }

    /**
     * @param argument List of sinks mapped to Power Query mashup query.
     */
    @JvmName("fwmigydhoxwiajls")
    public suspend fun dataflowSinks(vararg argument: suspend PowerQuerySinkArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            PowerQuerySinkArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.dataflowSinks = mapped
    }

    /**
     * @param argument List of sinks mapped to Power Query mashup query.
     */
    @JvmName("dlplxsnjdpcgyaws")
    public suspend fun dataflowSinks(argument: suspend PowerQuerySinkArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(PowerQuerySinkArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.dataflowSinks = mapped
    }

    /**
     * @param values List of sinks mapped to Power Query mashup query.
     */
    @JvmName("dadyvvthbrwoyqgr")
    public suspend fun dataflowSinks(vararg values: PowerQuerySinkArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dataflowSinks = mapped
    }

    /**
     * @param value Name of the query in Power Query mashup document.
     */
    @JvmName("bhfnxogfxmdwydew")
    public suspend fun queryName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.queryName = mapped
    }

    internal fun build(): PowerQuerySinkMappingArgs = PowerQuerySinkMappingArgs(
        dataflowSinks = dataflowSinks,
        queryName = queryName,
    )
}
